/*
 *  libfbx-mga.h -- Primary header for mga optimizations
 *  (C)opyright 2001 U4X Labs
 *
 *  Written by: Paul Mundt <lethal@u4xlabs.com>
 *
 *  $Id: libfbx-mga.h,v 1.15 2001/03/03 01:34:43 lethal Exp $
 *
 *  	This is the place for all the declarations of mga hardware
 *  specific optimizations for the libfbx system go.
 *
 *  See ChangeLog for modifications, CREDITS for credits.
 *
 *  All source herein is copyright U4X Labs and its original author. 
 *  Any code modifications or additions are (C)opyright the original 
 *  author and U4X Labs respectively.
 *
 *  libfbx is free software; you can redistribute it and/or modify it 
 *  under the terms of the GNU Lesser General Public License as 
 *  published by the Free Software Foundation; either version 2.1 of 
 *  the License, or (at your option) any later version.
 *
 *  libfbx is distributed in the hope that it will be useful, but 
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with libfbx; if not, write to the Free Software 
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */
#ifndef __LIBFBX_MGA_H
#define __LIBFBX_MGA_H

#include <libfbx/libfbx-drivers.h>
#include <stdlib.h>
#include <linux/types.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define M_SEQ_INDEX     0x1FC4
#define M_SEQ_DATA      0x1FC5

#define M_EXTVGA_INDEX  0x1FDE
#define M_EXTVGA_DATA   0x1FDF

#define M_DWG_TRAP      0x04
#define M_DWG_BITBLT	0x08
#define M_DWG_LINEAR	0x0080
#define M_DWG_SOLID     0x0800
#define M_DWG_ARZERO    0x1000
#define M_DWG_SGNZERO   0x2000
#define M_DWG_SHIFTZERO 0x4000
#define M_DWG_BMONOWF	0x08000000
#define M_DWG_REPLACE   0x000C0000

#define M_DWGCTL        0x1C00
#define M_FCOL          0x1C24
#define M_BCOL		0x1C20
#define M_FXBNDRY       0x1C84

#define M_FIFOSTATUS    0x1E10
#define M_STATUS        0x1E14
#define M_YDSTLEN       0x1C88
#define M_EXEC          0x0100

#define M_AR0		0x1C60
#define M_AR3		0x1C6C

typedef struct mga_accel_info {
	u_int32_t m_dwg_rect;
} mga_accel_info;

typedef struct mga_info {
	mga_accel_info *accel;
} mga_info;

extern mga_info *adapter;

/* libfbx-mga.c */
inline void mga_blank(int val);
void mga_fill_rect(__s32 x1, __s32 y1, __s32 x2, __s32 y2, __s32 r, __s32 g, __s32 b, fb_surface *surface);
void mga_putc(__s32 x, __s32 y, __u32 c);

/* libfbx-mga-misc.c */
inline void mga_wait_idle();
inline void mga_fifo(__u8 val);
inline void mga_ydstlen(__u32 y, __u32 l);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __LIBFBX_MGA_H */

