/*
 *  libfbx-arch.h -- Functions for Architecture Specific Optimizations
 *  (C)opyright 2000-2001 U4X Labs
 *
 *  Written by: Paul Mundt <lethal@u4xlabs.com>
 *              Thu Dec 28 22:13:39 EST 2000
 *
 *  $Id: libfbx-arch.h,v 1.11 2001/01/31 22:13:15 lethal Exp $
 *
 *      Wrappers for architecture specific routines.  Allows
 *  a function to call one routine (i.e. fb_memmove) that will
 *  be optimized if possible, but will redirect to the standard
 *  memmove if no architecture specific routine is available.
 * 
 *  See ChangeLog for modifications, CREDITS for credits.
 *
 *  All source herein is copyright U4X Labs and its original author.
 *  Any code modifications or additions are (C)opyright the original
 *  author and U4X Labs respectively.
 *
 *  libfbx is free software; you can redistribute it and/or modify it 
 *  under the terms of the GNU Lesser General Public License as 
 *  published by the Free Software Foundation; either version 2.1 of 
 *  the License, or (at your option) any later version.
 *
 *  libfbx is distributed in the hope that it will be useful, but 
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with libfbx; if not, write to the Free Software 
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */
#ifndef __LIBFBX_ARCH_H
#define __LIBFBX_ARCH_H

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <stdio.h>
#include <linux/types.h>

/* libfbx-memset.c */
inline void *fb_memset(void *s, int c, size_t n);

/* libfbx-memmove.c */
inline void *fb_memmove(void *d, const void *s, size_t count);

/* libfbx-endian.c */
inline int fb_determine_endianess();

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __LIBFBX_ARCH_H */

